@@ -12,15 +12,12 @@
 #include "kiten.h"
 
 #include <KActionCollection>
-#include <KConfig>
 #include <KConfigGui>
 #include <KEditToolBar>
 #include <KLocalizedString>
 #include <KProcess>
-#include <KShortcutsDialog>
 #include <KStandardAction>
 #include <KStandardGuiItem>
-#include <KStatusNotifierItem>
 #include <KToggleAction>
 #include <KXMLGUIFactory>
 
@@ -28,7 +25,6 @@
 #include <QApplication>
 #include <QClipboard>
 #include <QDockWidget>
-#include <QFile>
 #include <QList>
 #include <QPair>
 #include <QScrollBar>
@@ -45,8 +41,8 @@
 #include "kitenconfig.h"
 #include "resultsview.h"
 #include "searchstringinput.h"
-/* Separating Learn */
-// #include "learn.h"
+
+using namespace Qt::StringLiterals;
 
 Kiten::Kiten(QWidget *parent, const char *name)
     : KXmlGuiWindow(parent)
@@ -85,18 +81,11 @@ Kiten::Kiten(QWidget *parent, const char *name)
     _statusBar = statusBar();
     _optionDialog = nullptr;
 
-    /* Start the system tray icon. */
-    _sysTrayIcon = new KStatusNotifierItem(this);
-    _sysTrayIcon->setStandardActionsEnabled(true);
-    _sysTrayIcon->setAssociatedWidget(this);
-    _sysTrayIcon->setIconByName(QStringLiteral("kiten"));
-    _sysTrayIcon->setStatus(KStatusNotifierItem::Active);
-
     /* Set things as they were (as told in the config) */
     _autoSearchToggle->setChecked(_config->autosearch());
     _inputManager->setDefaultsFromConfig();
     updateConfiguration();
-    applyMainWindowSettings(KSharedConfig::openConfig()->group("kitenWindow"));
+    applyMainWindowSettings(KSharedConfig::openStateConfig()->group(QStringLiteral("kitenWindow")));
 
     /* What happens when links are clicked or things are selected in the clipboard */
     connect(_mainView, &ResultsView::urlClicked, this, &Kiten::searchText);
@@ -140,24 +129,14 @@ void Kiten::setupActions()
     // old style cast seems needed here, (const QObject*)
     KStandardAction::keyBindings(guiFactory(), &KXMLGUIFactory::showConfigureShortcutsDialog, actionCollection());
 
-    /* Setup the Go-to-learn-mode actions */
-    /* TODO: put back when Dictionary Editor is reorganised */
-    // 	(void) new KAction(   i18n( "&Dictionary Editor..." )
-    //                             , "document-properties"
-    //                             , 0
-    //                             , this
-    //                             , SLOT(createEEdit())
-    //                             , actionCollection()
-    //                             , "dict_editor");
     QAction *radselect = actionCollection()->addAction(QStringLiteral("radselect"));
     radselect->setText(i18n("Radical Selector"));
-    //	radselect->setIcon( "edit-find" );
-    actionCollection()->setDefaultShortcut(radselect, Qt::CTRL + Qt::Key_R);
+    actionCollection()->setDefaultShortcut(radselect, Qt::CTRL | Qt::Key_R);
     connect(radselect, &QAction::triggered, this, &Kiten::radicalSearch);
 
     QAction *kanjibrowser = actionCollection()->addAction(QStringLiteral("kanjibrowser"));
     kanjibrowser->setText(i18n("Kanji Browser"));
-    actionCollection()->setDefaultShortcut(kanjibrowser, Qt::CTRL + Qt::Key_K);
+    actionCollection()->setDefaultShortcut(kanjibrowser, Qt::CTRL | Qt::Key_K);
     connect(kanjibrowser, &QAction::triggered, this, &Kiten::kanjiBrowserSearch);
 
     /* Setup the Search Actions and our custom Edit Box */
@@ -195,23 +174,10 @@ void Kiten::setupActions()
 
     (void)KStandardAction::configureToolbars(this, SLOT(configureToolBars()), actionCollection());
 
-    // TODO: this should probably be a standard action
-    /*
-    globalShortcutsAction = actionCollection()->addAction( "options_configure_global_keybinding" );
-    globalShortcutsAction->setText( i18n( "Configure &Global Shortcuts..." ) );
-    connect( globalShortcutsAction, SIGNAL(triggered()), this, SLOT(configureGlobalKeys()) );
-    */
-
-    // TODO: implement this
-    //_globalSearchAction = actionCollection()->add<KToggleAction>( "search_on_the_spot" );
-    //_globalSearchAction->setText( i18n( "On The Spo&t Search" ) );
-    // KAction *temp = qobject_cast<KAction*>( _globalSearchAction );
-    // KShortcut shrt( "Ctrl+Alt+S" );
-    // globalSearchAction->setGlobalShortcut(shrt);  //FIXME: Why does this take ~50 seconds to return!?
-    // connect(globalSearchAction, SIGNAL(triggered()), this, SLOT(searchOnTheSpot()));
-
     _backAction = KStandardAction::back(this, SLOT(back()), actionCollection());
+    _backAction->setWhatsThis(i18n("Go to the previous search query."));
     _forwardAction = KStandardAction::forward(this, SLOT(forward()), actionCollection());
+    _forwardAction->setWhatsThis(i18n("Go to the next search query."));
     _backAction->setEnabled(false);
     _forwardAction->setEnabled(false);
 }
@@ -253,7 +219,7 @@ void Kiten::finishInit()
     // if it's the application's first time starting,
     // the app group won't exist and we show demo
     if (_config->initialSearch()) {
-        if (KConfigGui::hasSessionConfig() && !KConfigGui::sessionConfig()->hasGroup("app")) {
+        if (!KConfigGui::hasSessionConfig() || !KConfigGui::sessionConfig()->hasGroup(QStringLiteral("app"))) {
             searchTextAndRaise(QStringLiteral("辞書"));
             // Note to future tinkerers... DO NOT EDIT OR TRANSLATE THAT
             // it's an embedded unicode search string to find "dictionary" in japanese
@@ -277,7 +243,7 @@ bool Kiten::queryClose()
     _config->setAutosearch(_autoSearchToggle->isChecked());
     _config->save();
 
-    KConfigGroup configGroup = KSharedConfig::openConfig()->group("kitenWindow");
+    KConfigGroup configGroup = KSharedConfig::openStateConfig()->group(QStringLiteral("kitenWindow"));
     saveMainWindowSettings(configGroup);
     return true;
 }
@@ -451,7 +417,7 @@ void Kiten::displayResults(EntryList *results)
         results->sort(fieldSort, dictSort);
         _mainView->setContents(results->toHTML());
     } else {
-        _mainView->setContents("<html><body>" + infoStr + "</body></html>");
+        _mainView->setContents("<html><body>"_L1 + infoStr + "</body></html>"_L1);
     }
 
     _mainView->setLaterScrollValue(results->scrollValue());
@@ -464,13 +430,6 @@ void Kiten::displayResults(EntryList *results)
     */
 }
 
-/*
-void Kiten::searchOnTheSpot()
-{
-  qDebug() << "On the spot search!\n";
-}
-*/
-
 void Kiten::radicalSearch()
 {
     // Radselect is a KUniqueApplication, so we don't
@@ -497,43 +456,14 @@ void Kiten::slotConfigure()
 
     // ConfigureDialog didn't find an instance of this dialog, so lets create it :
     _optionDialog = new ConfigureDialog(this, _config);
-    connect(_optionDialog, SIGNAL(hidden()), this, SLOT(slotConfigureHide()));
     connect(_optionDialog, &ConfigureDialog::settingsChanged, this, &Kiten::updateConfiguration);
 
     _optionDialog->show();
 }
 
-/**
- * This function just queues up slotConfigureDestroy() to get around the
- * SIGSEGV if you try to delete yourself if you are in the stack.
- */
-void Kiten::slotConfigureHide()
-{
-    QTimer::singleShot(0, this, &Kiten::slotConfigureDestroy);
-}
-
-/**
- * This function actually tears down the optionDialog
- */
-void Kiten::slotConfigureDestroy()
-{
-    if (_optionDialog != nullptr && _optionDialog->isVisible() == 0) {
-        delete _optionDialog;
-        _optionDialog = nullptr;
-    }
-}
-
-/* TODO: reimplement something very much like this
-void Kiten::createEEdit()
-{
-  eEdit *_eEdit = new eEdit( PERSONALDictionaryLocation( "data" ), this );
-  _eEdit->show();
-}
-*/
-
 void Kiten::configureToolBars()
 {
-    KConfigGroup configGroup = KSharedConfig::openConfig()->group("kitenWindow");
+    KConfigGroup configGroup = KSharedConfig::openStateConfig()->group(QStringLiteral("kitenWindow"));
     saveMainWindowSettings(configGroup);
     KEditToolBar dlg(actionCollection());
     connect(&dlg, &KEditToolBar::newToolBarConfig, this, &Kiten::newToolBarConfig);
@@ -543,16 +473,10 @@ void Kiten::configureToolBars()
 void Kiten::newToolBarConfig()
 {
     createGUI(QStringLiteral("kitenui.rc"));
-    KConfigGroup configGroup = KSharedConfig::openConfig()->group("kitenWindow");
+    KConfigGroup configGroup = KSharedConfig::openStateConfig()->group(QStringLiteral("kitenWindow"));
     applyMainWindowSettings(configGroup);
 }
 
-/** Opens the dialog for configuring the global accelerator keys. */
-void Kiten::configureGlobalKeys()
-{
-    KShortcutsDialog::showDialog(actionCollection(), KShortcutsEditor::LetterShortcutsAllowed, this);
-}
-
 /**
  * This function, as the name says, updates the configuration file.
  * It should be called in EVERY case where the configuration files change.
@@ -606,7 +530,7 @@ void Kiten::loadDictionaries()
  */
 void Kiten::loadDictConfig(const QString &dictType)
 {
-    KConfigGroup group = _config->config()->group("dicts_" + dictType.toLower());
+    KConfigGroup group = _config->config()->group("dicts_"_L1 + dictType.toLower());
 
     // A list of QPair's Name->Path
     QList<QPair<QString, QString>> dictionariesToLoad;
